@@ -5,6 +5,7 @@ import docx
 from nltk.stem import WordNetLemmatizer
 from docx.opc.constants import RELATIONSHIP_TYPE as RT
 import win32com.client as win32
+import glob
 
 
 
@@ -139,10 +140,14 @@ phone_pattern = re.compile(r"(\d{3}[-.\s]??\d{3}[-.\s]??\d{4}|\(\d{3}\)\s*\d{3}[
 
 passport_pattern = re.compile(r"\b[A-Z]+\d+[A-Z\d]*\b")
 
-name_pattern = re.compile(r"\b[A-Z][A-Za-z]+ [A-Z][A-Za-z]+\b")
-
+name_pattern = re.compile(r"\b[a-zA-Z][A-Za-z]+ [a-zA-Z][A-Za-z]+\b")
 
 def file_conv(dir_path):
+    for file in glob.glob(os.path.join(dir_path, "*.rtf")):
+        root, ext = os.path.splitext(file)
+        if ext == ".rtf":
+            new_path = root + ".doc"
+            os.rename(file, new_path)
     files = os.listdir(dir_path)
     non_inluded = []
     for f in files:
@@ -159,14 +164,6 @@ def file_conv(dir_path):
                 doc.Close()
                 word.Quit()
                 print(f , ": doc conversion done")
-
-            elif f.endswith('.rtf') :
-                word = win32.Dispatch("Word.Application")
-                doc = word.Documents.Open(os.path.join(dir_path,f))
-                doc.SaveAs(os.path.join(dir_path, f.replace('.rtf', '.docx')), FileFormat=12)
-                doc.Close()
-                word.Quit()
-                print(f , ": rtf conversion done")
         except:
             print(f , ": this rtf conversion failed reasons may be - File format not supported / read only document format")
             non_inluded.append(f)
